@@ -1,15 +1,12 @@
 
 
-jagsUI <- jags <- function(data,inits=NULL,parameters.to.save,model.file,n.chains,n.adapt=100,n.iter,n.burnin=0,n.thin=1,
-                       modules=c('glm'),parallel=FALSE,n.cores=NULL,DIC=TRUE,store.data=FALSE,codaOnly=FALSE,seed=as.integer(Sys.time()),
+jagsUI <- jags <- function(data,inits=NULL,parameters.to.save,model.file,n.chains,n.adapt=NULL,n.iter,n.burnin=0,n.thin=1,
+                       modules=c('glm'),factories=NULL,parallel=FALSE,n.cores=NULL,DIC=TRUE,store.data=FALSE,codaOnly=FALSE,seed=NULL,
                        bugs.format=FALSE,verbose=TRUE){
   
-  #Set random seed
-  RNGkind('default')
-  set.seed(seed)
-  
   #Pass input data and parameter list through error check / processing
-  data.check <- process.input(data,parameters.to.save,inits,n.chains,n.iter,n.burnin,n.thin,n.cores,DIC=DIC,verbose=verbose,parallel=parallel)
+  data.check <- process.input(data,parameters.to.save,inits,n.chains,n.iter,n.burnin,n.thin,n.cores,DIC=DIC,
+                              verbose=verbose,parallel=parallel,seed=seed)
   data <- data.check$data
   parameters.to.save <- data.check$params
   inits <- data.check$inits
@@ -22,9 +19,12 @@ jagsUI <- jags <- function(data,inits=NULL,parameters.to.save,model.file,n.chain
   if(parallel && n.chains>1){
  
   par <- run.parallel(data,inits,parameters.to.save,model.file,n.chains,n.adapt,n.iter,n.burnin,n.thin,
-                      modules,seed,DIC,verbose=verbose,n.cores=n.cores) 
+                      modules,factories,seed,DIC,verbose=verbose,n.cores=n.cores) 
   samples <- par$samples
   m <- par$model
+  total.adapt <- par$total.adapt
+  sufficient.adapt <- par$sufficient.adapt
+  if(any(!sufficient.adapt)&verbose){warning("JAGS reports adaptation was incomplete. Consider increasing n.adapt")}
     
   } else {
     
@@ -34,10 +34,13 @@ jagsUI <- jags <- function(data,inits=NULL,parameters.to.save,model.file,n.chain
   
   #Set modules
   set.modules(modules,DIC)
+  set.factories(factories)
   
   rjags.output <- run.model(model.file,data,inits,parameters.to.save,n.chains,n.iter,n.burnin,n.thin,n.adapt,verbose=verbose)
   samples <- rjags.output$samples
   m <- rjags.output$m
+  total.adapt <- rjags.output$total.adapt
+  sufficient.adapt <- rjags.output$sufficient.adapt
   
   ##########################
   ##End of rjags functions##
@@ -53,8 +56,8 @@ jagsUI <- jags <- function(data,inits=NULL,parameters.to.save,model.file,n.chain
   #Combine mcmc info into list
   n.samples <- dim(samples[[1]])[1] * n.chains
   end.values <- samples[(n.samples/n.chains),]
-  mcmc.info <- list(n.chains,n.adapt,n.iter,n.burnin,n.thin,n.samples,end.values,time)
-  names(mcmc.info) <- c('n.chains','n.adapt','n.iter','n.burnin','n.thin','n.samples','end.values','elapsed.mins')
+  mcmc.info <- list(n.chains,n.adapt=total.adapt,sufficient.adapt,n.iter,n.burnin,n.thin,n.samples,end.values,time)
+  names(mcmc.info) <- c('n.chains','n.adapt','sufficient.adapt','n.iter','n.burnin','n.thin','n.samples','end.values','elapsed.mins')
   if(parallel){mcmc.info$n.cores <- n.cores}
   
   #Reorganize JAGS output to match input parameter order
@@ -84,6 +87,7 @@ jagsUI <- jags <- function(data,inits=NULL,parameters.to.save,model.file,n.chain
   output$random.seed <- seed
   output$parallel <- parallel
   output$bugs.format <- bugs.format
+  output$DIC <- DIC
   
   #Classify final output object
   class(output) <- 'jagsUI'
